==> ckeditor5_premium_features-1.3.4.tar.gz: ckeditor5_premium_features/src/CKEditorPremiumPluginsCheckerTrait.php <==
<?php

/*
 * Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see https://ckeditor.com/legal/ckeditor-oss-license
 */

declare(strict_types=1);

namespace Drupal\ckeditor5_premium_features;

/**
 * Trait for checking if in array of plugins are premium features.
 */
trait CKEditorPremiumPluginsCheckerTrait {

  /**
   * @param array $plugins
   * @return bool
   */
  private function hasPremiumFeaturesEnabled(array $config, $editor = FALSE): bool {
    $label = $editor ? $editor->getFilterFormat()->get('name') : '';
    if (isset($config['plugins']) && isset($config['plugins']['ckeditor5_premium_features_productivity_pack_base'])) {
      if (in_array(TRUE, $config['plugins']['ckeditor5_premium_features_productivity_pack_base'], TRUE)) {
        if ($label) {
          \Drupal::logger('ckeditor5_premium_features_ubb_debug')->info('%label Productivity pack is enabled. %plugin', ['%plugin' => print_r($plugin, TRUE), '%label' => $label]);
        }
        return TRUE;
      }
    }

    if (isset($config['toolbar']['items']) && array_intersect($this->getPremiumToolbarItems(), $config['toolbar']['items'])) {
      if ($label) {
        \Drupal::logger('ckeditor5_premium_features_ubb_debug')->info('%label Toolbar item without settings is enabled.', ['%label' => $label]);
      }
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Returns array of premium features toolbar items.
   *
   * @return array
   */
  private function getPremiumToolbarItems(): array {
    return [
      'aiAssistant',
      'aiCommands',
      'caseChange',
      'comment',
      'commentsArchive',
      'exportPdf',
      'exportWord',
      'formatPainter',
      'importWord',
      'insertTemplate',
      'multiLevelList',
      'revisionHistory',
      'tableOfContents',
      'trackChanges'
    ];
  }
}

==> ckeditor5_premium_features-1.3.5.tar.gz: ckeditor5_premium_features/src/CKEditorPremiumPluginsCheckerTrait.php <==
<?php

/*
 * Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see https://ckeditor.com/legal/ckeditor-oss-license
 */

declare(strict_types=1);

namespace Drupal\ckeditor5_premium_features;

/**
 * Trait for checking if in array of plugins are premium features.
 */
trait CKEditorPremiumPluginsCheckerTrait {

  /**
   * @param array $plugins
   * @return bool
   */
  private function hasPremiumFeaturesEnabled(array $config): bool {
    if (isset($config['plugins']) && isset($config['plugins']['ckeditor5_premium_features_productivity_pack_base'])) {
      if (in_array(TRUE, $config['plugins']['ckeditor5_premium_features_productivity_pack_base'], TRUE)) {
        return TRUE;
      }
    }

    if (isset($config['toolbar']['items'])) {
      $enabledPremiumPlugins = array_intersect($this->getPremiumToolbarItems(), $config['toolbar']['items']);
      // Check the case when only insertTemplate is enabled. It can be enabled through Plugin Pack in that case it's
      // not considered as premium feature.
      if (!$enabledPremiumPlugins) {
        return FALSE;
      }
      if (count($enabledPremiumPlugins) === 1 && in_array('insertTemplate', $enabledPremiumPlugins, TRUE)) {
        $moduleHandler = \Drupal::service('module_handler');
        if ($moduleHandler->moduleExists('ckeditor5_plugin_pack_templates')) {
          return FALSE;
        }
      }
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Returns array of premium features toolbar items.
   *
   * @return array
   */
  private function getPremiumToolbarItems(): array {
    return [
      'aiAssistant',
      'aiCommands',
      'caseChange',
      'comment',
      'commentsArchive',
      'exportPdf',
      'exportWord',
      'formatPainter',
      'importWord',
      'insertTemplate',
      'multiLevelList',
      'revisionHistory',
      'tableOfContents',
      'trackChanges'
    ];
  }
}
